@@ -94,7 +94,7 @@ def main():
 			f.write(enc_mpwd)
 			vault.set_hid_dir()
 		try:
-			os.makedirs(self.hid_path)
+			os.makedirs(vault.hid_dir[:-1])
 		except FileExistsError:
 			pass
 		print("Welcome")
